<?php
/**
 * Plugin Name: Highlight to Speech
 * Plugin URI: ipasssas.com
 * Description: Converts highlighted text to speech using ResponsiveVoice.js library.
 * Version: 1.0
 * Author: Iordanis Passas
 * Author URI: ipassas.com
 * License: GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 */

function highlight_tts_enqueue_scripts() {
    wp_enqueue_script('responsive-voice', 'https://code.responsivevoice.org/responsivevoice.js', array(), '1.0', true);
    wp_enqueue_script('highlight-tts', plugin_dir_url(__FILE__) . 'highlight-tts.js', array('jquery'), '1.0', true);
    wp_enqueue_style('highlight-tts-style', plugin_dir_url(__FILE__) . 'highlight-tts.css');

    // Get the existing settings
    $settings = get_option('highlight_tts_settings', array());

    // If no icon is set in the settings, use the default icon
    if (!isset($settings['icon']) || empty($settings['icon'])) {
        $settings['icon'] = plugin_dir_url(__FILE__) . 'assets/mic.png';
    }

    // If no post types are set in the settings, set it as an empty array
    if (!isset($settings['post_types']) || !is_array($settings['post_types'])) {
        $settings['post_types'] = array();
    }

// Get current post type
global $post;
$post_type = get_post_type($post);
if ($post_type) {
    $settings['current_post_type'] = $post_type;
}

    // Pass the settings to your JavaScript code
    wp_localize_script('highlight-tts', 'HighlightTTSSettings', $settings);
}
add_action('wp_enqueue_scripts', 'highlight_tts_enqueue_scripts');


function highlight_tts_add_options_page() {
    add_options_page('Highlight TTS Settings', 'Highlight TTS', 'manage_options', 'highlight-tts', 'highlight_tts_options_page');
}
add_action('admin_menu', 'highlight_tts_add_options_page');

function highlight_tts_post_types_callback() {
    $options = get_option('highlight_tts_settings');
    $post_types = isset($options) && is_array($options) && isset($options['post_types']) ? $options['post_types'] : array();

    // get all the public post types
    $all_post_types = get_post_types(array('public' => true), 'names');
    
    foreach ($all_post_types as $post_type) {
        $checked = in_array($post_type, $post_types) ? 'checked' : '';
        echo '<input type="checkbox" name="highlight_tts_settings[post_types][]" value="' . $post_type . '" ' . $checked . '> ' . $post_type . '<br />';
    }
}

function highlight_tts_options_page() {
    wp_enqueue_media();

    ?>
    <div class="wrap">
        <h1>Highlight to Speech Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('highlight-tts');
            do_settings_sections('highlight-tts');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

function highlight_tts_register_settings() {
    register_setting('highlight-tts', 'highlight_tts_settings');
    add_settings_section('highlight-tts-general', 'General Settings', null, 'highlight-tts');
    add_settings_field('post_types', 'Allowed Post Types for TTS', 'highlight_tts_post_types_callback', 'highlight-tts', 'highlight-tts-general');
    add_settings_field('voice', 'Voice', 'highlight_tts_voice_callback', 'highlight-tts', 'highlight-tts-general');
    add_settings_field('icon_size', 'Icon Size', 'highlight_tts_icon_size_callback', 'highlight-tts', 'highlight-tts-general');
    add_settings_field('icon', 'Icon', 'highlight_tts_icon_callback', 'highlight-tts', 'highlight-tts-general');
}
add_action('admin_init', 'highlight_tts_register_settings');

function highlight_tts_voice_callback() {
    $options = get_option('highlight_tts_settings');
    $voice = isset($options) && is_array($options) && isset($options['voice']) ? $options['voice'] : '';
    ?>
    <select name="highlight_tts_settings[voice]">
        <option value="male" <?php selected($voice, 'male'); ?>>Male</option>
        <option value="female" <?php selected($voice, 'female'); ?>>Female</option>
    </select>
    <?php
}

function highlight_tts_icon_size_callback() {
    $options = get_option('highlight_tts_settings');
    $icon_size = isset($options) && is_array($options) && isset($options['icon_size']) ? $options['icon_size'] : '';
    ?>
    <input type="number" name="highlight_tts_settings[icon_size]" value="<?php echo esc_attr($icon_size); ?>" />
    <?php
}

function highlight_tts_icon_callback() {
    $options = get_option('highlight_tts_settings');
    $icon = isset($options) && is_array($options) && isset($options['icon']) ? $options['icon'] : '';
    ?>
    <input type="text" id="highlight-tts-icon-url" name="highlight_tts_settings[icon]" value="<?php echo esc_attr($icon); ?>" />
    <input type="button" id="highlight-tts-icon-button" class="button-secondary" value="Choose Image" />
    <script>
    jQuery(document).ready(function($) {
        $('#highlight-tts-icon-button').click(function(e) {
            e.preventDefault();
            var custom_uploader = wp.media({
                title: 'Custom Image',
                button: {
                    text: 'Use this image'
                },
                multiple: false  // Set this to true to allow multiple files to be selected
            })
            .on('select', function() {
                var attachment = custom_uploader.state().get('selection').first().toJSON();
                $('#highlight-tts-icon-url').val(attachment.url);
            })
            .open();
        });
    });
    </script>
    <?php
}
?>
